#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 ghcide
version:              2.3.0.0
visibility:           public
id:                   ghcide-2.3.0.0-5ssdDHVSHun4CTi9Kh39ZX
key:                  ghcide-2.3.0.0-5ssdDHVSHun4CTi9Kh39ZX
license:              Apache-2.0
copyright:            Digital Asset and Ghcide contributors 2018-2020
maintainer:           Ghcide contributors
author:               Digital Asset and Ghcide contributors
homepage:
    https://github.com/haskell/haskell-language-server/tree/master/ghcide#readme

synopsis:             The core of an IDE
description:          A library for building Haskell IDE'\''s on top of the GHC API.
category:             Development
abi:                  91979a7a36a6d44c862ef668bea7e91e
exposed:              True
exposed-modules:
    Control.Concurrent.Strict Development.IDE
    Development.IDE.Core.Actions Development.IDE.Core.Compile
    Development.IDE.Core.Debouncer Development.IDE.Core.FileStore
    Development.IDE.Core.FileUtils
    Development.IDE.Core.IdeConfiguration
    Development.IDE.Core.OfInterest Development.IDE.Core.PluginUtils
    Development.IDE.Core.PositionMapping
    Development.IDE.Core.Preprocessor
    Development.IDE.Core.ProgressReporting
    Development.IDE.Core.RuleTypes Development.IDE.Core.Rules
    Development.IDE.Core.Service Development.IDE.Core.Shake
    Development.IDE.Core.Tracing Development.IDE.Core.UseStale
    Development.IDE.GHC.Compat Development.IDE.GHC.Compat.Core
    Development.IDE.GHC.Compat.Env Development.IDE.GHC.Compat.Iface
    Development.IDE.GHC.Compat.Logger
    Development.IDE.GHC.Compat.Outputable
    Development.IDE.GHC.Compat.Parser
    Development.IDE.GHC.Compat.Plugins Development.IDE.GHC.Compat.Units
    Development.IDE.GHC.Compat.Util Development.IDE.GHC.CoreFile
    Development.IDE.GHC.Error Development.IDE.GHC.Orphans
    Development.IDE.GHC.Util
    Development.IDE.Import.DependencyInformation
    Development.IDE.Import.FindImports
    Development.IDE.LSP.HoverDefinition
    Development.IDE.LSP.LanguageServer
    Development.IDE.LSP.Notifications Development.IDE.LSP.Outline
    Development.IDE.LSP.Server Development.IDE.Main
    Development.IDE.Main.HeapStats Development.IDE.Monitoring.EKG
    Development.IDE.Monitoring.OpenTelemetry Development.IDE.Plugin
    Development.IDE.Plugin.Completions
    Development.IDE.Plugin.Completions.Types Development.IDE.Plugin.HLS
    Development.IDE.Plugin.HLS.GhcIde Development.IDE.Plugin.Test
    Development.IDE.Plugin.TypeLenses Development.IDE.Session
    Development.IDE.Session.Diagnostics Development.IDE.Spans.AtPoint
    Development.IDE.Spans.Common Development.IDE.Spans.Documentation
    Development.IDE.Spans.LocalBindings Development.IDE.Spans.Pragmas
    Development.IDE.Types.Diagnostics Development.IDE.Types.Exports
    Development.IDE.Types.HscEnvEq Development.IDE.Types.KnownTargets
    Development.IDE.Types.Location Development.IDE.Types.Monitoring
    Development.IDE.Types.Options Development.IDE.Types.Shake
    Generics.SYB.GHC Text.Fuzzy.Parallel

hidden-modules:
    Development.IDE.Core.FileExists Development.IDE.GHC.CPP
    Development.IDE.GHC.Warnings
    Development.IDE.Plugin.Completions.Logic
    Development.IDE.Session.VersionCheck Development.IDE.Types.Action

import-dirs:          /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/ghcide-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-ghcide
hs-libraries:         HSghcide-2.3.0.0-5ssdDHVSHun4CTi9Kh39ZX
depends:
    Diff-1.0-EyI2PwVDvqcHEZdhq20a3S Glob-0.10.2-8s0wbnBYMNO3GH6wkOA3t6
    aeson-2.2.2.0-C59vZnSjH3DEmVbOnYEZqj array-0.5.6.0
    async-2.2.6-B1xPYkcAzs1LAdhNFIgAnG base-4.18.2.1
    base16-bytestring-1.0.2.0-LOzdqrPOAmvA9dBRBt8wdk binary-0.8.9.1
    bytestring-0.11.5.3 case-insensitive-1.2.1.0-2Yyf9IxnGFQLPP0jk4pg3Q
    co-log-core-0.3.2.7-Cy0Nnp4RGB9JCnUMoyNgrD containers-0.6.7
    cryptohash-sha1-0.11.101.0-4z9YPazGkkw2elIgzmGVb2
    data-default-0.7.1.3-v65wBq6p7UHdeTWfWwzRF deepseq-1.4.8.1
    dependent-map-0.4.0.1-2zJACcI0koyFP5NiKTmv1F
    dependent-sum-0.7.2.0-IcjknoC6D7DFwrTtYaRu9s directory-1.3.8.5
    dlist-1.0-1Hu4TU8l65oIz4v1ZjWgTZ
    enummapset-0.7.3.0-7D7MWFYBXyzIT6hVp6EdVd exceptions-0.10.7
    extra-1.7.16-DutWM4qj2UOFoGYeyZgh2s filepath-1.4.300.1
    fingertree-0.1.6.3-62TdxI168FNGHE9uv02ymQ
    focus-1.0.3.2-8A04vTkhkN5As8WOUicK9R ghc-9.6.6 ghc-boot-9.6.6
    ghc-boot-th-9.6.6 ghc-check-0.5.0.8-9rpxtJPP8tAIcj6Q1k0r26
    ghc-paths-0.1.0.12-JSGGj7CcxjZ2Iy0LlOG5cZ
    ghc-trace-events-0.1.2.10-H26I0MYftT2GE85bySiIsN
    haddock-library-1.11.0-81YK0ELPXnW5bhLL1SLTYB
    hashable-1.4.7.0-DeckboSXRoV2uaWXBDn9RA
    hie-bios-0.12.0-CRSGEUnL3rI1wguWImzBzV
    hie-compat-0.3.1.2-37lTPgU0jdr1Ufn5QvEKoZ
    hiedb-0.4.3.0-9k23BwHqzOPJQgKbPlmg9n
    hls-graph-2.3.0.0-BKCw9wgtA1S1PhMBjmLsTw
    hls-plugin-api-2.3.0.0-4xBXilkZH7I1XWpO94lJCk
    implicit-hie-0.1.4.0-8Avdsqfr4E73BhxRmabP8i
    implicit-hie-cradle-0.5.0.1-HmGSliDDabXHAi2U5eDSDO
    lens-5.3.5-BDZkiRzgsgQ2kD9evujAJa
    list-t-1.0.5.7-HMtVR61ldoMCBQgiB4e0r0
    lsp-2.2.0.0-6w4y1QddwBxGRyqRyrutmt
    lsp-types-2.0.2.0-G7lljheWjPRDy3eZeBztoD mtl-2.3.1
    opentelemetry-0.8.0-DqdGNyWpO25GgL0O14ZPjv
    optparse-applicative-0.18.1.0-JRbhqUMlTBkCWkkrIaelno
    parallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD
    prettyprinter-1.7.2-HvkUgaUIGC1QRxB5LZpIj
    prettyprinter-ansi-terminal-1.1.4-EAIDjuz92O98ensOsTLpTk
    random-1.2.1.3-2D6Xw54bvJBUzxlFqHjEz
    regex-tdfa-1.3.2.5-9aVe6H9O9607zCidRganW5
    row-types-1.0.1.2-7S0vgI9avfg4bfoPAHvMsQ
    safe-exceptions-0.1.7.4-2nheImLyyBWAYQkT0m3AQ1
    sorted-list-0.2.3.1-Dw2jBkOjRbbHUKzWeOSEji
    sqlite-simple-0.4.19.0-FodiOxVO6zNIAKXPjeRkt6 stm-2.5.1.0
    stm-containers-1.2.1.1-LiPcfcx1vHlZF91q1RRvq
    syb-0.7.3-11K0viXu9hkJBGIPMEQMvn text-2.0.2
    text-rope-0.3-1tPcjFedDu7CXlXWX6d47x time-1.12.2
    transformers-0.6.1.0 unix-2.8.4.0
    unliftio-0.2.25.1-JwtBWAs5WUC67yAeM1UF4A
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.21-LjCRrPGX8vKp2UxAfh6M2
    vector-0.13.2.0-HJSwbt845rQ2AOZrNm5BDk

haddock-interfaces:   /usr/share/doc/haskell-ghcide/html/ghcide.haddock
haddock-html:         /usr/share/doc/haskell-ghcide/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

